==> libqt4pas_2.4.orig.tar.gz: splitbuild-qt4pas-V2.4_Qt4.5.3/src/qscrollarea_c.h <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QSCROLLAREA_C_H
#define QSCROLLAREA_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QScrollAreaH QScrollArea_create(QWidgetH parent);
C_EXPORT void QScrollArea_destroy(QScrollAreaH handle);
C_EXPORT QWidgetH QScrollArea_widget(QScrollAreaH handle);
C_EXPORT void QScrollArea_setWidget(QScrollAreaH handle, QWidgetH widget);
C_EXPORT QWidgetH QScrollArea_takeWidget(QScrollAreaH handle);
C_EXPORT bool QScrollArea_widgetResizable(QScrollAreaH handle);
C_EXPORT void QScrollArea_setWidgetResizable(QScrollAreaH handle, bool resizable);
C_EXPORT void QScrollArea_sizeHint(QScrollAreaH handle, PSize retval);
C_EXPORT bool QScrollArea_focusNextPrevChild(QScrollAreaH handle, bool next);
C_EXPORT unsigned int QScrollArea_alignment(QScrollAreaH handle);
C_EXPORT void QScrollArea_setAlignment(QScrollAreaH handle, unsigned int p1);
C_EXPORT void QScrollArea_ensureVisible(QScrollAreaH handle, int x, int y, int xmargin, int ymargin);
C_EXPORT void QScrollArea_ensureWidgetVisible(QScrollAreaH handle, QWidgetH childWidget, int xmargin, int ymargin);

#endif

==> libqt4pas_2.5.orig.tar.gz: splitbuild-qt4pas-V2.5_Qt4.5.3/src/qscrollarea_c.h <==
//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QSCROLLAREA_C_H
#define QSCROLLAREA_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QScrollAreaH QScrollArea_create(QWidgetH parent);
C_EXPORT void QScrollArea_destroy(QScrollAreaH handle);
C_EXPORT QWidgetH QScrollArea_widget(QScrollAreaH handle);
C_EXPORT void QScrollArea_setWidget(QScrollAreaH handle, QWidgetH widget);
C_EXPORT QWidgetH QScrollArea_takeWidget(QScrollAreaH handle);
C_EXPORT bool QScrollArea_widgetResizable(QScrollAreaH handle);
C_EXPORT void QScrollArea_setWidgetResizable(QScrollAreaH handle, bool resizable);
C_EXPORT void QScrollArea_sizeHint(QScrollAreaH handle, PSize retval);
C_EXPORT bool QScrollArea_focusNextPrevChild(QScrollAreaH handle, bool next);
C_EXPORT unsigned int QScrollArea_alignment(QScrollAreaH handle);
C_EXPORT void QScrollArea_setAlignment(QScrollAreaH handle, unsigned int AnonParam1);
C_EXPORT void QScrollArea_ensureVisible(QScrollAreaH handle, int x, int y, int xmargin, int ymargin);
C_EXPORT void QScrollArea_ensureWidgetVisible(QScrollAreaH handle, QWidgetH childWidget, int xmargin, int ymargin);

#endif
